[![PyPI version](https://badge.fury.io/py/Highton.svg)](https://badge.fury.io/py/Highton) [![Current Docs](https://readthedocs.org/projects/highton/badge/?version=latest)](http://highton.readthedocs.io/en/latest/)

Highton
===========

## A Python-based API-wrapper for Highrise

From v2.0 on, the codebase is completely rewritten from scratch.    
So please only upgrade if you are willing to touch your implementation as well.


## Features List:

| Endpoint | State |
|-------|-----:|
|People   |:white_check_mark:|
|Categories (Tasks, Deals)|:white_check_mark:|
|Companies | :white_check_mark:|
|Cases | :white_check_mark:|
|Deals | :white_check_mark:|
|Notes | :white_check_mark:|
|Emails | :white_check_mark:|
|Comments | :white_check_mark:|
|Tags | :white_check_mark:|
|Tasks | :white_check_mark:|
|Users | :white_check_mark:|
|Groups | :white_check_mark:|
|Memberships | :x:|
|Account | :x:|
|Parties | :x:|
|Recordings | :x:|
|Custom Fields (Subject fields) | :white_check_mark:|
|Deletions | :x:|
